## Count number of pdb-files in dir
##
## Reads calculated PDB files, and writes official PDB-format

import os
import string

pdbbestand=read('ALD_ensemble.pdb')     # Xplor compatible input file
outfile='ALD_PDBform.pdb'		# PDB compatible output file

def cd(newdir):
	os.chdir(str(newdir))
	
def ls(dir):
	return os.listdir(dir)
	
def pwd():
	return os.getcwd()

def read(textfile):
    """Read textfile into strings, and puts it in a list\n\nSyntax:\nread('[path]/[filename]\n"""
    
    tmp=open(textfile,'r')
    file=tmp.readlines()
    tmp.close()

    data=[]
    for i in range (0,len(file)):
        data.append(string.split(file[i]))
    return data

def xplor2pdb(pdbin,pdbout):	#needs definifion read()
	"""Reads calculated PDB-files and writes official PDB format
	Syntax:\nxplor2pdb(pdbin,pdboutfile)"""
	at=0 	#atomline counter (both ATOM and HETATM)
	r=0	#remark line counter
	het=0	#HET records
	helix=0 #helix records
	s=0	#sheet records
	t=0	#turn records
	site=0	#site records
	trans=0	#transformation records
	ter=0	#number of TER records
	con=0	#number of CONECT records
	seq=0	#number of SEQRES records
	
	atomline=[]
	hetatmline=[]
	remarkline=[]
	for p in range(0,len(pdbin)):				#filling ATOM-lines
		if len(pdbin[p])<>0 and pdbin[p][0]=='ATOM':
			at=at+1
			start=''
			for q in range(0,len(pdbin[p])):
				new=start+' '+pdbin[p][q]
				start=new
			atomline.append(new)
		if len(pdbin[p])<>0 and pdbin[p][0]=='HETATM':	#filling HETATM lines
			at=at+1
			start=''
			for q in range(0,len(pdbin[p])):
				new=start+' '+pdbin[p][q]
				start=new
			hetatmline.append(new)	
		if len(pdbin[p])<>0 and pdbin[p][0][0:6] in ['REMARK','MODEL ','ENDMDL']:	#filling REMARK# lines
			r=r+1
			start=''
			for q in range(0,len(pdbin[p])):
				new=start+' '+pdbin[p][q]
				start=new
			remarkline.append(new)
	
	
	pdbout=open(outfile,'w')
	
	for q in range(0,len(remarkline)):				#writing remarklines
		pdbout.write(remarkline[q][1:len(remarkline[q])]+'\n')
	
	pdbout.write('MODEL        1\n')
	
	for q in range(0,len(atomline)):				#Converting and writing ATOM-lines
		# stringformat ATOM-lines
		#
		# a=ATOM, b=atomnumber, c=atomname, d=alternate location (1 charracter), e=residue name (3), f=chainID, g=res.nr
		# h=insertion code (1 char), x,y,z=coordinates, i=occupancy (6 numbers total, 2 decimals), j=temp. factor
		# k=segid (max four letters), l=element, m=charge on atom
		d=' '
		f='A'
		h=' '
		
		m='1.5'
		
		tmp=string.split(atomline[q])
		if len(string.split(atomline[q]))<>11:			#check for onestrings -###-####-###
			for i in range(0,len(tmp)-1):
				if tmp[i].find('-')<>-1:
					tmp2=tmp[i].split('-')
					for j in range(1,len(tmp2)):
						tmp2[j]='-'+tmp2[j]
					if tmp2[0]=='':
						del tmp2[0]
					tmp[i:len(tmp2)]=tmp2
					del tmp[i+len(tmp2)]
		
		[a,b,c,e,g,x,y,z,i,j,k]=tmp
		
		e=e[0]
		b=int(b)
		g=int(g)
		x=float(x)
		y=float(y)
		z=float(z)
		i=float(i)
		j=float(j)
		m=float(m)
		l=c[0]	
		if c=="H2''":			#insert from awk script							#choose element
			c="HO2'"
		if c=="H5''":
			c="H5\""
		#if c.find("'")<>-1:								#eliminate prime-notations
		#	c=c[0:c.find("'")]+'*'
		if c=='H41' or c=='H42' or c=='H21' or c=='H22' or c=='H61' or c=='H62':	#renaming H41 H42 etc.
			c2=c[-1]+c[0:len(c)-1]
			c=c2
		atom="ATOM  "+"%5d %4s%1s%3s %1s%4s%1s   %8.3f%8.3f%8.3f%6.2f%6.2f      %4s%2s%2d\n" % (q+1,c,d,e,f,g,h,x,y,z,i,j,k,l,m)
		pdbout.write(atom)
	
	
	for q in range(0,len(hetatmline)):				#Converting and writing HETATM-lines
		# stringformat ATOM-lines
		#
		# a=ATOM, b=atomnumber, c=atomname, d=alternate location (1 charracter), e=residue name (3), f=chainID, g=res.nr
		# h=insertion code (1 char), x,y,z=coordinates, i=occupancy (6 numbers total, 2 decimals), j=temp. factor
		# k=segid (max four letters), l=element, m=charge on atom
		d=' '
		f='A'
		h=' '
		
		m='1'
		tmp=string.split(hetatmline[q])
		if len(string.split(hetatmline[q]))<>11:			#check for onestrings -###-####-###
			for i in range(0,len(tmp)-1):
				if tmp[i].find('-')<>-1:
					tmp2=tmp[i].split('-')
					for j in range(1,len(tmp2)):
						tmp2[j]='-'+tmp2[j]
					if tmp2[0]=='':
						del tmp2[0]
					tmp[i:len(tmp2)]=tmp2
					del tmp[i+len(tmp2)]
		
		[a,b,c,e,g,x,y,z,i,j,k]=tmp
		
		e=e[0]
		b=int(b)
		g=int(g)
		x=float(x)
		y=float(y)
		z=float(z)
		i=float(i)
		j=float(j)
		m=float(m)
		l=c[0]					#choose element
		#if c.find("'")<>-1:			#eliminate prime-notations
		#	c=c[0:c.find("'")-1]+'*'
		
		atom="ATOM  "+"%5d  %3s%1s%3s %1s%4s%1s   %8.3f%8.3f%8.3f%6.2f%6.2f      %4s%2s%2d\n" % (b,c,d,e,f,g,h,x,y,z,i,j,k,l,m)
		pdbout.write(atom)
	
	
	
	
	term="TER   "+"%5d%6s%3s%2s\n" % (b+1,d,e,f)		#writing TER rule
	ter=ter+1
	pdbout.write(term)
	pdbout.write('ENDMDL\n')
	
	
	zero=0
	master='MASTER    '+"%5d%5d%5d%5d%5d%5d%5d%5d%5d%5d%5d%5d\n" % (r,zero,het,helix,s,t,site,trans,at,ter,con,seq)
	pdbout.write(master)
	pdbout.write('END\n')
		
	pdbout.close()

######### User defined variables and input
tmp=open(outfile,'w')
tmp.close()
atomcount=0
for i in range(0,len(pdbbestand)):
	if pdbbestand[i][0]<>'ATOM':
		if pdbbestand[i][0]<>'ENDMDL':
			if pdbbestand[i][0]<>'MODEL':
				tmp=open(outfile,'a')
				newline=''
				for j in range(0,len(pdbbestand[i])):
					newline=newline+' '+pdbbestand[i][j]
				newline=newline+'\n'
				tmp.write(newline)
	if pdbbestand[i][0]=='ATOM':
		atomcount=atomcount+1
		[label,atcnt,attp,resn,resi,x,y,z,h,j,k]=pdbbestand[i]
		atcnt=int(atcnt)
		label=str(label)
		resi=int(resi)
		x=float(x)
		y=float(y)
		z=float(z)
		h=float(h)
		j=float(j)	
		chainid='A'
		segid='EDHB'
		if attp=="H2''":			#insert from awk script							#choose element
			attp="HO2'"
		if attp=="H5''":
			attp="H5\""
		#if attp.find("'")<>-1:								#eliminate prime-notations
		#	attp=attp[0:attp.find("'")]+'*'
		#Comment in if H41 should be 4H1
		#if attp=='H41' or attp=='H42' or attp=='H21' or attp=='H22' or attp=='H61' or attp=='H62':	#renaming H41 H42 etc.
		#	attp2=attp[-1]+attp[0:len(attp)-1]
		#	attp=attp2
		chemic=attp[0]
		atom="ATOM "+"%6d %-4s   %1s%2s  %2s    %8.3f%8.3f%8.3f%6.2f%6.2f %11s\n" % (atomcount,attp,resn[0],chainid,resi,x,y,z,h,j,chemic)
		tmp=open(outfile,'a')
		tmp.write(atom)
	if pdbbestand[i][0]=='ENDMDL':
		atomcount=atomcount+1
		attp=' '
		atom="TER   "+"%5d%-5s   %1s%2s  %2s\n" % (atomcount,attp,resn[0],chainid,resi)
		tmp=open(outfile,'a')
		tmp.write(atom)
		tmp.write('ENDMDL\n')
		tmp.close()
	if pdbbestand[i][0]=='MODEL':
		newline='MODEL     %s\n' % (pdbbestand[i][1])
		tmp=open(outfile,'a')
		tmp.write(newline)
		tmp.close()
